@@ -4,13 +4,6 @@ class NoEmbeddingException(Exception):
     """
 
 
-class CannotInferModelVersionException(Exception):
-    """
-    Exception gets risen when a version is supplied but also files that are not relevant to that version
-    (e.g. version = 1 + vocabulary file).
-    """
-
-
 class MissingParameterError(Exception):
     """
     Exception for missing parameters
@@ -23,24 +16,12 @@ class InvalidParameterError(Exception):
     """
 
 
-class CannotFindDefaultFile(Exception):
-    """
-    Exception for invalid file download request
-    """
-
-
 class SequenceTooLongException(Exception):
     """
     Exception when trying to embed sequences longer then the limit
     """
 
 
-class SequenceEmbeddingLengthMismatchException(Exception):
-    """
-    Exception when trying to embed sequences longer then the limit
-    """
-
-
 class MD5ClashException(Exception):
     """
     When remapping sequences from a fasta file, if there is an MD5 clash, this will stop the execution
@@ -50,4 +31,22 @@ class MD5ClashException(Exception):
 class TooFewComponentsException(InvalidParameterError):
     """
     Thrown when n_components is nonsensical (e.g. < 2)
+    """
+
+
+class ConversionUniqueMismatch(Exception):
+    """
+    Thrown when trying to remap using a mapping file which doesn't have as many uniuqye original_ids as md5 hashes
+    """
+
+
+class UnrecognizedEmbeddingError(Exception):
+    """
+    Thrown when trying to access embeddings for sequences which have no embedding.
+    """
+
+
+class InvalidAnnotationFileError(Exception):
+    """
+    Thrown when an annotation file contains invalid values
     """
\ No newline at end of file
